package app.views.table;

import app.data.service.PlayerService;
import app.navigation.NavigationLevel;
import app.navigation.NavigationService;
import app.views.main.MainView;
import app.views.navigation.NavigationViewBase;
import app.views.table.components.TableCard;
import com.vaadin.flow.component.dependency.CssImport;
import com.vaadin.flow.router.PageTitle;
import com.vaadin.flow.router.Route;
import com.vaadin.flow.router.RouteAlias;
import org.springframework.beans.factory.annotation.Autowired;

@CssImport("app/views/table/table-view.css")
@Route(value = "table", layout = MainView.class)
@RouteAlias(value = "", layout = MainView.class)
@PageTitle("Schachliga DACH - Table")
public class TableView extends NavigationViewBase {

    private final PlayerService playerService;

    private TableCard tableCard;

    public TableView(@Autowired NavigationService navigationService,
                     @Autowired PlayerService playerService) {
        super(navigationService, "table", NavigationLevel.MATCHDAY);
        this.playerService = playerService;

        this.navigation.setOnlyMatchdaysWithActivity(true);

        addClassName("table-view");

        defineLayout();
    }

    ////////////
    // LAYOUT //
    ////////////

    private void defineLayout() {
        tableCard = new TableCard(navigation, playerService);
        add(tableCard);
    }

    /////////////
    // CONTENT //
    /////////////

    @Override
    protected void configureContent() {
        tableCard.configureContent();
    }
}
